import { Subject } from 'rxjs';
import { TabExpViewBase } from '@/studio-core';
import GoalService from '@/service/goal/goal-service';
import TabExpViewEngine from '@engine/view/tab-exp-view-engine';

/**
 * 目标分页状态视图基类
 *
 * @export
 * @class GoalStateTabViewBase
 * @extends {TabExpViewBase}
 */
export class GoalStateTabViewBase extends TabExpViewBase {

    /**
     * 视图对应应用实体名称
     *
     * @protected
     * @type {string}
     * @memberof GoalStateTabViewBase
     */
    protected appDeName: string = 'goal';

    /**
     * 实体服务对象
     *
     * @type {GoalService}
     * @memberof GoalStateTabViewBase
     */
    protected appEntityService: GoalService = new GoalService;


    /**
     * 计数器服务对象集合
     *
     * @protected
     * @type {Array<*>}
     * @memberof GoalStateTabViewBase
     */    
    protected counterServiceArray: Array<any> = [];

    /**
     * 视图模型数据
     *
     * @protected
     * @type {*}
     * @memberof GoalStateTabViewBase
     */
    protected model: any = {
        srfCaption: 'entities.goal.views.statetabview.caption',
        srfTitle: 'entities.goal.views.statetabview.title',
        srfSubTitle: 'entities.goal.views.statetabview.subtitle',
        dataInfo: ''
    }

    /**
     * 容器模型
     *
     * @protected
     * @type {*}
     * @memberof GoalStateTabViewBase
     */
    protected containerModel: any = {
        view_tabexppanel: { name: 'tabexppanel', type: 'TABEXPPANEL' },
    };


	/**
     * 视图唯一标识
     *
     * @protected
     * @type {string}
     * @memberof ViewBase
     */
	protected viewtag: string = '2f0540af5db76052cee0e8e91f0204c4';


    /**
     * 视图引擎
     *
     * @public
     * @type {Engine}
     * @memberof GoalStateTabViewBase
     */
    public engine: TabExpViewEngine = new TabExpViewEngine();

    /**
     * 引擎初始化
     *
     * @public
     * @memberof GoalStateTabViewBase
     */
    public engineInit(): void {
        this.engine.init({
            view: this,
            keyPSDEField: 'goal',
            majorPSDEField: 'title',
            isLoadDefault: true,
        });
    }



    /**
     * 加载模型
     *
     * @protected
     * @memberof GoalStateTabViewBase
     */
    protected async loadModel(): Promise<any> {
        if(this.context.goal){
            this.appEntityService.getDataInfo(JSON.parse(JSON.stringify(this.context)),{},false).then((response:any) =>{
                if (!response || response.status !== 200) {
                    return;
                }
                const { data: _data } = response;
                if (_data.title) {
                    Object.assign(this.model, { dataInfo: _data.title });
                    if(this.$route){
                        this.$route.meta.info = this.model.dataInfo;
                    }
                    Object.assign(this.model, { srfTitle: `${this.$t(this.model.srfTitle)} - ${this.model.dataInfo}` });
                    this.$appService.navHistory.setCaption({ tag: this.viewtag, info: this.model.dataInfo });
                }
            })
        }
    }


}