import { Subject } from 'rxjs';
import { TabExpViewBase } from '@/studio-core';
import LeadService from '@/service/lead/lead-service';
import TabExpViewEngine from '@engine/view/tab-exp-view-engine';

/**
 * 潜在顾客视图基类
 *
 * @export
 * @class LeadStatusTabViewBase
 * @extends {TabExpViewBase}
 */
export class LeadStatusTabViewBase extends TabExpViewBase {

    /**
     * 视图对应应用实体名称
     *
     * @protected
     * @type {string}
     * @memberof LeadStatusTabViewBase
     */
    protected appDeName: string = 'lead';

    /**
     * 实体服务对象
     *
     * @type {LeadService}
     * @memberof LeadStatusTabViewBase
     */
    protected appEntityService: LeadService = new LeadService;


    /**
     * 计数器服务对象集合
     *
     * @protected
     * @type {Array<*>}
     * @memberof LeadStatusTabViewBase
     */    
    protected counterServiceArray: Array<any> = [];

    /**
     * 视图模型数据
     *
     * @protected
     * @type {*}
     * @memberof LeadStatusTabViewBase
     */
    protected model: any = {
        srfCaption: 'entities.lead.views.statustabview.caption',
        srfTitle: 'entities.lead.views.statustabview.title',
        srfSubTitle: 'entities.lead.views.statustabview.subtitle',
        dataInfo: ''
    }

    /**
     * 容器模型
     *
     * @protected
     * @type {*}
     * @memberof LeadStatusTabViewBase
     */
    protected containerModel: any = {
        view_tabexppanel: { name: 'tabexppanel', type: 'TABEXPPANEL' },
    };


	/**
     * 视图唯一标识
     *
     * @protected
     * @type {string}
     * @memberof ViewBase
     */
	protected viewtag: string = '3202f3f503424c7a2c549b2c5186dc36';


    /**
     * 视图引擎
     *
     * @public
     * @type {Engine}
     * @memberof LeadStatusTabViewBase
     */
    public engine: TabExpViewEngine = new TabExpViewEngine();

    /**
     * 引擎初始化
     *
     * @public
     * @memberof LeadStatusTabViewBase
     */
    public engineInit(): void {
        this.engine.init({
            view: this,
            keyPSDEField: 'lead',
            majorPSDEField: 'fullname',
            isLoadDefault: true,
        });
    }



    /**
     * 加载模型
     *
     * @protected
     * @memberof LeadStatusTabViewBase
     */
    protected async loadModel(): Promise<any> {
        if(this.context.lead){
            this.appEntityService.getDataInfo(JSON.parse(JSON.stringify(this.context)),{},false).then((response:any) =>{
                if (!response || response.status !== 200) {
                    return;
                }
                const { data: _data } = response;
                if (_data.fullname) {
                    Object.assign(this.model, { dataInfo: _data.fullname });
                    if(this.$route){
                        this.$route.meta.info = this.model.dataInfo;
                    }
                    Object.assign(this.model, { srfTitle: `${this.$t(this.model.srfTitle)} - ${this.model.dataInfo}` });
                    this.$appService.navHistory.setCaption({ tag: this.viewtag, info: this.model.dataInfo });
                }
            })
        }
    }


}